@@ -63,7 +63,7 @@ class TalismanAPIAdapter:
         self.document_fields_truncated = ('id', 'external_url')
         self.document_fields = (
             'id', 'title', 'external_url', 'publication_author', 'publication_date', 'internal_url', 'markers',
-            'system_registration_date', 'system_update_date', 'access_level', 'trust_level'
+            'system_registration_date', 'system_update_date', 'notes', 'access_level', 'trust_level'
         )
         self.document_fields_extended = (
             'id', 'title', 'publication_author', 'publication_date', 'external_url',
@@ -453,6 +453,10 @@ class TalismanAPIAdapter:
         dt.metadata().text_translations().language().id()
         cd = d.list_child()
         cd.__fields__(*self.document_fields)
+        cd.last_updater().__fields__(*self.user_fields)
+        cd.metadata().platform().__fields__(*self.document_platform_fields)
+        cd.metadata().account().__fields__(*self.document_account_fields)
+        cd.creator().__fields__(*self.user_fields)
         cdt = cd.text(show_hidden=True)
         cdt.__fields__(*self.document_text_fields)
         cdt.metadata().__fields__(*self.document_text_metadata_fields)
